from flarestack.data.icecube.ps_tracks.ps_v002_p01 import ps_v002_p01
from flarestack.data.icecube.ps_tracks.ps_v002_p03 import ps_v002_p03
from flarestack.data.icecube.ps_tracks.ps_v003_p01 import ps_v003_p01
from flarestack.data.icecube.ps_tracks.ps_v003_p02 import ps_v003_p02
from flarestack.data.icecube.ps_tracks.ps_v004_p00 import ps_v004_p00
from flarestack.data.icecube.northern_tracks.nt_v002_p05 import nt_v002_p05
from flarestack.data.icecube.northern_tracks.nt_v005_p00 import nt_v005_p00
from flarestack.data.icecube.gfu.gfu_v002_p01 import gfu_v002_p01, txs_sample_v1
from flarestack.data.icecube.gfu.gfu_v002_p02 import gfu_v002_p02, txs_sample_v2
from flarestack.data.icecube.gfu.gfu_v002_p04 import gfu_v002_p04
from flarestack.data.icecube.ic_season import icecube_dataset_dir

ps_7_year = ps_v002_p01
ps_10_year = ps_v003_p02
diffuse_8_year = nt_v002_p05
gfu_8_year = gfu_v002_p04
